# TableCellLocation

Location of a single cell within a table.

**Type:** object

## Properties

- **tableStartLocation** ([Location](location.md)): The location where the table starts in the document.
- **rowIndex** (integer): The zero-based row index. For example, the second row in the table has a row index of 1.
- **columnIndex** (integer): The zero-based column index. For example, the second column in the table has a column index of 1.
